==> prestashop-1.4.9.0.tbz: www/prestashop/mails/de/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();
$_LANGMAIL['Welcome!'] = 'Willkommen!';
$_LANGMAIL['Message from contact form'] = 'Nachricht aus dem Kontaktformular';
$_LANGMAIL['Your message has been correctly sent'] = 'Ihre Nachricht ist korrekt gesendet worden';
$_LANGMAIL['New credit slip regarding your order'] = 'Gutschrift zu Ihrer Bestellung';
$_LANGMAIL['Virtual product to download'] = 'Der Download Ihres virtuellen Produktes wurde freigeschaltet und steht jetzt zur Verfügung';
$_LANGMAIL['Fwd: Customer message'] = 'Fwd: Kundennachricht';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Ihr Gast-Konto wurde in ein Kunden-Konto umgewandelt';
$_LANGMAIL['Package in transit'] = 'Paket versendet';
$_LANGMAIL['[Log'] = 'Sie haben ein Log-Alert aus Ihrem Shop erhalten';
$_LANGMAIL['Order confirmation'] = 'Automatische Bestellbestätigung';
$_LANGMAIL['Message from a customer'] = 'Nachricht eines Kunden';
$_LANGMAIL['New message regarding your order'] = 'Neue Nachricht zu Ihrer Bestellung';
$_LANGMAIL['Your order return state has changed'] = 'Der Status Ihrer Bestellung hat sich geändert';
$_LANGMAIL['Your password'] = 'Ihr Kennwort wurde zurückgesetzt';
$_LANGMAIL['Password query confirmation'] = 'Bestätigung der Kennwortänderung';
$_LANGMAIL['An answer to your message is available'] = 'Sie haben eine Antwort auf Ihre Nachricht erhalten';
$_LANGMAIL['New voucher regarding your order'] = 'Neuer Gutschein zu Ihrer Bestellung';
$_LANGMAIL['Happy birthday!'] = 'Alles Gute zum Geburtstag!';
$_LANGMAIL['Newsletter confirmation'] = 'Bestätigung Ihrer Anmeldung zu unserem Newsletter';
$_LANGMAIL['Newsletter voucher'] = 'Newsletter-Gutschein';
$_LANGMAIL['Your wishlist\\\'s link'] = 'Ihr Wunschlisten-Link';
$_LANGMAIL['Message from '] = 'Nachricht von';
$_LANGMAIL['$subject'] = 'Betreff';
$_LANGMAIL['Your cart and your discount'] = 'Gutschein zu Ihrem offenen Warenkorb';
$_LANGMAIL['Thanks for your order'] = 'Wir danken für Ihren Auftrag';
$_LANGMAIL['You are one of our best customers'] = 'Sie sind einer unserer besten Kunden';
$_LANGMAIL['We miss you'] = 'Wir danken für Ihr Vertrauen';
$_LANGMAIL['Product available'] = 'Produkt wieder verfügbar';
$_LANGMAIL['Product out of stock'] = 'Produkt leider ausverkauft';
$_LANGMAIL['Error reporting from your PayPal module'] = 'Fehlerbericht aus Ihrem PayPal Modul';
$_LANGMAIL['Congratulations!'] = 'Herzlichen Glückwunsch!';
$_LANGMAIL['Referral Program'] = 'Empfehlungsprogramm';
$_LANGMAIL['A friend sent you a link to'] = 'Ein Freund hat Ihnen einen Link gesendet';
$_LANGMAIL['Your order return state has changed'] = 'Der Status Ihrer Rücksendung wurde geändert';

==> prestashop-1.5.3.1.tbz: www/prestashop/mails/de/lang.php <==
<?php

global $_LANGMAIL;
$_LANGMAIL = array();

$_LANGMAIL['New credit slip regarding your order'] = 'Gutschrift zu Ihrer Bestellung';
$_LANGMAIL['Your guest account has been transformed to customer account'] = 'Ihr Gast-Konto wurde in ein Kunden-Konto umgewandelt';
$_LANGMAIL['Message from a customer'] = 'Nachricht eines Kunden';
$_LANGMAIL['Your new password'] = 'Ihr neues Kennwort';
$_LANGMAIL['Newsletter confirmation'] = 'Bestätigung Ihrer Anmeldung zu unserem Newsletter';
$_LANGMAIL['Newsletter voucher'] = 'Newsletter-Gutschein';
$_LANGMAIL['Message from %1$s %2$s'] = 'Nachricht von %1$s %2$s';
$_LANGMAIL['Your cart and your discount'] = 'Gutschein zu Ihrem offenen Warenkorb';
$_LANGMAIL['%1$s sent you a link to %2$s'] = '%1$s hat Ihnen einen Link von %2$s geschickt';
$_LANGMAIL['Package in transit'] = 'Paket versendet';
$_LANGMAIL['Log: You have a new alert from your shop'] = 'Sie haben ein Log-Alert aus Ihrem Shop erhalten';
$_LANGMAIL['Password query confirmation'] = 'Bestätigung der Kennwortänderung';
$_LANGMAIL['An answer to your message is available #ct%1$s #tc%2$s'] = 'Sie haben eine Antwort auf Ihre Nachricht erhalten #ct%1$s #tc%2$s';
$_LANGMAIL['You are one of our best customers'] = 'Sie sind einer unserer besten Kunden';
$_LANGMAIL['Welcome!'] = 'Willkommen!';
$_LANGMAIL['Fwd: Customer message'] = 'Fwd: Kundennachricht';
$_LANGMAIL['Order confirmation'] = 'Automatische Bestellbestätigung';
$_LANGMAIL['New message regarding your order'] = 'Neue Nachricht zu Ihrer Bestellung';
$_LANGMAIL['New voucher regarding your order %s'] = 'Neuer Gutschein zu Ihrer Bestellung %s';
$_LANGMAIL['Thanks for your order'] = 'Wir danken für Ihren Auftrag';
$_LANGMAIL['We miss you'] = 'Wir danken für Ihr Vertrauen';
$_LANGMAIL['Congratulations!'] = 'Gratulation';
$_LANGMAIL['Message from contact form'] = 'Nachricht aus dem Kontaktformular';
$_LANGMAIL['Your message has been correctly sent'] = 'Ihre Nachricht ist korrekt gesendet worden';
$_LANGMAIL['Your order return state has changed'] = 'Der Status Ihrer Rücksendung wurde geändert';
$_LANGMAIL['Product available'] = 'Produkt wieder verfügbar';
$_LANGMAIL['Product out of stock'] = 'Produkt leider ausverkauft';
